@@ -212,24 +212,25 @@ class Sylo:
         self.tasks = get_tasks(date)
         self.input_loop()
 
-    def new_task_menu(self, date: str):
+    def new_task_menu(self, dates: List):
         clear_screen()
         task = Task()
-        self.tasks = get_tasks(date)
         display.print_header_small()
-        display.print_tasks(self.tasks)
+        for date in dates:
+            self.tasks = get_tasks(date)
+            display.print_tasks(self.tasks)
         display.print_add_task_or_quit()
         usr_input = input(cursor)
         if usr_input.lower() == "q":
             self.input_loop()
-        if usr_input == "":
+        while usr_input == "":
             display.print_new_task()
             task.description = input('Description >> ')
             task.write_task_to_file()
             display.print_another_task()
             another_yn = input(cursor)
             if another_yn.lower() == "y":
-                self.new_task_menu(date)
+                continue
             else:
                 self.input_loop()
 
@@ -313,7 +314,7 @@ class Sylo:
         while response.lower() == "a":
             self.task_menu()
         while response.lower() == "n":
-            self.new_task_menu(TODAY_STR)
+            self.new_task_menu([YESTERDAY_STR, TODAY_STR, ])
         while response == "":
             self.timer_loop(timer)
 
